@@ -1,5 +1,5 @@
 import time
-import information
+from . import information
 import requests
 
 
@@ -62,7 +62,7 @@ class Robot:
     def send_music_sharing(self, wxid, name, author, app, jumpUrl, musicUrl, imageUrl):
         type_ = "Q0014"
         data_ = {"type": f"{type_}",
-                 "data": {"wxid": f"{wxid}",
+                 "data": {"wxid": "wxid_at1vbqt6zgg922",
                           "name": "我也",
                           "author": "无名",
                           "app": "wx8dd6ecd81906fd84",
